@@ -96,24 +96,25 @@ def extract_many(soup : BeautifulSoup, **selectors) -> list:
         info must be written in following manner:
             first key is 'tag' with value as tag from where data is obtained
             second key is 'attrs' with value as dict containing id or class information
+            third key is 'output': which specifies type of data recieved: text, href or src
         Valid Examples:
-            title =  {'tag' : 'h2', 'attrs' : {'class':'a-size-mini a-spacing-none a-color-base s-line-clamp-2'}}
-            priceDict = {'tag' : 'span', 'attrs' : {'class' : 'a-price-whole'}}
+            title =  {'tag' : 'h2', 'attrs' : {'class':'a-size-mini a-spacing-none a-color-base s-line-clamp-2'}, output = 'text'}
+            priceDict = {'tag' : 'span', 'attrs' : {'class' : 'a-price-whole'}, output = 'text'}
         
         target is a special selector and can be added to specify which section of html code should data be extracted from
         Example of target use:
-            target = {'tag' : 'div', 'attrs' : {'class':'s-main-slot s-result-list s-search-results sg-row'}}
+            target = {'tag' : 'div', 'attrs' : {'class':'s-main-slot s-result-list s-search-results sg-row'}, output = 'text'}
         
         items is a mandatory selector which refers to the repeating blocks of html code from soup object
         Example of item use:
-            items =  {'tag' : 'div', 'attrs' : {'class':'s-result-item'}}
-
+            items =  {'tag' : 'div', 'attrs' : {'class':'s-result-item'}, output = 'text'}
+        
         Valid call: 
             soup = get_webpage_data("https://www.amazon.com/s?k=headphones&crid=1DUUWW6PEVAJ1&sprefix=headphones%2Caps%2C161&ref=nb_sb_noss_1")
             extract_many(soup, 
-                target = {'tag' : 'div', 'attrs' : {'class':'s-main-slot s-result-list s-search-results sg-row'}},
-                items =  {'tag' : 'div', 'attrs' : {'class':'s-result-item'}},
-                title =  {'tag' : 'h2', 'attrs' : {'class':'a-size-mini a-spacing-none a-color-base s-line-clamp-2'}})
+                target = {'tag' : 'div', 'attrs' : {'class':'s-main-slot s-result-list s-search-results sg-row'}, output = 'text'},
+                items =  {'tag' : 'div', 'attrs' : {'class':'s-result-item'}, output = 'text'},
+                title =  {'tag' : 'h2', 'attrs' : {'class':'a-size-mini a-spacing-none a-color-base s-line-clamp-2'}, output = 'text'})
     """
     if 'target' in selectors:
         tag = selectors['target'].get('tag')
@@ -123,7 +124,6 @@ def extract_many(soup : BeautifulSoup, **selectors) -> list:
             print("Example: target = {'tag' : 'div', 'attrs' : {...}")
             return None
         else:
-            print(soup)
             target = soup.find(tag, attrs)
             if target is None:
                 print(f"Could not find target section with this {tag} and {attrs}")
@@ -164,5 +164,38 @@ def extract_many(soup : BeautifulSoup, **selectors) -> list:
             return data_list
     else:
         print("items is required as a parameter containing dict containing tag, attrs as keys")
-        print("Example: items = {'tag' : 'div', 'attrs' : {...}")
-    
\ No newline at end of file
+        print("Example: items = {'tag' : 'div', 'attrs' : {...}, output = 'text'")
+
+def extract_urls(soup : BeautifulSoup, target = None) -> list:
+    """
+    Obtains all the urls from given website
+    Returns all urls in a list
+    
+    Args:
+    soup (BeautifulSoup): Contains entire page data as BeautifulSoup object. URLs will be extracted from this object
+    target (dict): target is an optional arg and can be added to specify which section of html code should urls be extracted from
+    """
+    if target is not None:
+        tag = target.get('tag')
+        attrs = target.get('attrs')
+        if tag is None:
+            print("Please give valid selectors")
+            print("Example: target = {'tag' : 'div', 'attrs' : {...}")
+            return None
+        else:
+            target = soup.find(tag, attrs)
+            if target is None:
+                print(f"Could not find target section with this {tag} and {attrs}")
+                return None
+    else:
+        target = soup
+    url_list = target.find_all('a'); links = set()
+    try:
+        for link in url_list:
+            url = link.attrs.get('href')
+            if url:
+                if url != "#":
+                    links.add(url)
+    except Exception as e:
+        print("Could not filter links")
+    return list(links)
\ No newline at end of file
